@@ -137,7 +137,7 @@ class IndexGraph(Graph):
 
         # The engine and the aggregator must be specified for an index service
         self.engine = self._default_engine(engine_type, metric=metric, replicas=replicas, shards=shards, name="engine")
-        self.aggregator = self._default_aggregator(num_shards=shards, name="aggregator")
+        self.aggregator = None if shards == 1 else self._default_aggregator(num_shards=shards, name="aggregator")
         self._update_graph()
 
     def add_postprocessor(self, image_uri: str = None, config: dict = None, fn: Function = None):
@@ -168,7 +168,7 @@ class IndexGraph(Graph):
     def add_preprocessor(self, path: str, image_uri: str = None, config: dict = None, fn: Function = None):
         """Adds a preprocessor to the given path of the graph.
 
-        You can add mutiple preprocessors to the same path in a graph.
+        You can add multiple preprocessors to the same path in a graph.
         ``query`` requests flow through the read path of the graph,
         and ``upsert`` requests flow through the write path of the graph.
 
