@@ -11,11 +11,18 @@ def init_tracer():
     enable_tracing = distutils.util.strtobool(os.getenv('DD_TRACING_ENABLED', default='False'))
     if not enable_tracing:
         os.environ['DD_TRACE_STARTUP_LOGS'] = 'False'
-    from ddtrace import tracer
+    from ddtrace import tracer, patch_all
     from ddtrace.contrib import asyncio
     tracer.enabled = enable_tracing
     tracer.context_provider = asyncio.context_provider
     logging.disable(logging.WARNING)
+    patch_all()
+
+
+def init_profiler():
+    enable_profiling = distutils.util.strtobool(os.getenv('DD_PROFILING_ENABLED', default='False'))
+    if enable_profiling:
+        import ddtrace.profiling.auto
 
 
 def get_msg_size(msg: 'core_pb2.Request'):
